function y = BMPrice(L,beta,a,b,c,tau,PutCall,S0,K,r,q,T,N)

% Brigo, Mercurio, and Rapisarda Option price based on lognormal mixtures
% by Fabrice Douglas Rouah, FRouah.com and Volopta.com

% Indicator for put or call
if strcmp(PutCall,'C')
    w = 1;
elseif strcmp(PutCall,'P')
    w = -1;
end

% Black Scholes prices
for i=1:N
    % Eta functions for integrated variance
    eta(i) = a(i) + b(i)*(1-exp(-T/tau(i)))*(tau(i)/T) + c(i)*exp(-T/tau(i));
    LSK = log((S0-beta(i))/K);
    % Check that logarithm exists
    if isreal(LSK)
        d1 = w*(LSK + (r-q+0.5*eta(i)^2)*T)/eta(i)/sqrt(T);
        d2 = w*(LSK + (r-q-0.5*eta(i)^2)*T)/eta(i)/sqrt(T);
        Option(i) = L(i)*((S0-beta(i))*exp((r-q)*T)*normcdf(d1) - K*normcdf(d2));
    else
        Option(i) = 1e100;
    end
end

y = w*exp(r*T)*sum(Option);

